pub struct ServerSettings {
pub tick_rate: NonZeroU32,
pub compression_threshold: CompressionThreshold,
}Fields
tick_rate: NonZeroU32The target ticks per second (TPS) of the server. This is the number of game updates that should occur in one second.
On each game update (tick), the server is expected to update game logic and respond to packets from clients. Once this is complete, the server will sleep for any remaining time until a full tick duration has passed.
Note that the official Minecraft client only processes packets at 20hz, so there is little benefit to a tick rate higher than the default 20.
Default Value
compression_threshold: CompressionThresholdThe compression threshold to use for compressing packets. For a
compression threshold of Some(N), packets with encoded lengths >= N
are compressed while all others are not. None disables compression
completely.
If the server is used behind a proxy on the same machine, you will likely want to disable compression.
Default Value
Compression is enabled with an unspecified value. This value may change in future versions.